==> blesta-5.10.2.zip: blesta/plugins/webhooks/language/tr_tr/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POSTA';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Giden';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Gelen';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'Parametrenin adı 255 karakteri geçemez.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'Alanın parametresi boş olamaz.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'Alanın adı 255 karakteri geçemez.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'Alanın adı boş olamaz.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Lütfen geçerli bir yöntem seçin.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Lütfen geçerli bir tür seçin.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'Sağlanan olay mevcut değil.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'Geri arama 255 karakteri geçemez.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Lütfen geçerli bir geri arama girin.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Bu türde bir web kancası bu geri arama ile zaten mevcuttur.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Sağlanan şirket mevcut değildir.';

==> blesta-5.11.4.zip: blesta/plugins/webhooks/language/tr_tr/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POSTA';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Giden';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Gelen';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'Parametrenin adı 255 karakteri geçemez.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'Alanın parametresi boş olamaz.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'Alanın adı 255 karakteri geçemez.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'Alanın adı boş olamaz.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Lütfen geçerli bir yöntem seçin.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Lütfen geçerli bir tür seçin.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'Sağlanan olay mevcut değil.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'Geri arama 255 karakteri geçemez.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Lütfen geçerli bir geri arama girin.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Bu türde bir web kancası bu geri arama ile zaten mevcuttur.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Sağlanan şirket mevcut değildir.';
$lang['WebhooksWebhooks.getMethods.put_json'] = 'PUT JSON';
$lang['WebhooksWebhooks.getMethods.post_json'] = 'POST JSON';
$lang['WebhooksWebhooks.getMethods.put'] = 'PUT';
$lang['WebhooksWebhooks.!error.events[].exists'] = 'Sağlanan olay mevcut değil.';
